//
//  ChatView.swift
//  Chat
//
//  Created by Sergey Tarasov on 24.07.2022.
//

import SwiftUI
import XMPPFramework
import XMPPFrameworkSwift

extension CGFloat {
    static let sidePadding: CGFloat = 14
}

struct ChatView: View {
    @StateObject var viewModel: ChatViewModel

    var body: some View {
        VStack(alignment: .center, spacing: 0) {
			ChatMessageListView(messages: viewModel.messages)
            Divider()
			MessageTextField(message: $viewModel.messageText, action: viewModel.sendMessage)
        }
        .navigationTitle(viewModel.room.roomJID.user ?? "Room")
        .navigationBarTitleDisplayMode(.inline)
        .toolbar {
            ToolbarItem(placement: .navigationBarTrailing) {
                Button {
                    viewModel.fetchMessages()
                } label: {
                    Image(systemName: "arrow.counterclockwise")
                }
            }
        }
    }
}

struct ChatView_Previews: PreviewProvider {
    static var viewModel: ChatViewModel = ChatViewModel(with: "jid")

    static var previews: some View {
        Group {
			NavigationView {
				ChatView(viewModel: viewModel)
			}
        }
    }
}
